<?php
/**
 * Create a set of form items to be displayed on the form for editing this
 * component. Use care naming the form items, as this correlates directly to the
 * database schema. The component "Name" and "Description" fields are added to
 * every component type and are not necessary to specify here (although they may
 * be overridden if desired).
 * @return
 *   An array of form items to be displayed on the edit component page.
 */
function _webform_edit_number($currfield) {
  $edit_fields = array(
    '#validate' => array('_webform_edit_number_validate' => array()),
  );
  
   
  
  $edit_fields['value'] = array(
    '#type' => 'textfield',
    '#title' => t("Default value"),
    '#default_value' => $currfield['value'],
    '#description' => t('The default value of the field.') .'<br />'. webform_help('webform/helptext#variables'),
    '#size' => 60,
    '#maxlength' => 127,
    '#weight' => 0,
    '#attributes' => ($currfield['value'] == '%usernumber' && count(form_get_errors()) == 0) ? array('disabled' => TRUE) : array(),
    '#id' => 'number-value',
  );
  
  $edit_fields['extra']['field_prefix'] = array(
	 	     '#type' => 'textfield',
	 	     '#title' => t("Label placed to the left of the textfield"),
	 	     '#default_value' => $currfield['extra']['field_prefix'],
	 	     '#description' => t('Examples: $, #, -.'),
	 	     '#size' => 20,
	 	     '#maxlength' => 127,
	 	     '#weight' => 1.1,
			 );
$edit_fields['extra']['field_suffix'] = array(
	 	     '#type' => 'textfield',
	 	     '#title' => t("Label placed to the right of the textfield"),
	 	     '#default_value' => $currfield['extra']['field_suffix'],
	 	     '#description' => t('Examples: lb, kg, %.'),
	 	     '#size' => 20,
	 	     '#maxlength' => 127,
	 	     '#weight' => 1.2,
  );
  
  
  
  $edit_fields['extra']['width'] = array(
    '#type' => 'textfield',
    '#title' => t("Width"),
    '#default_value' => $currfield['extra']['width'],
    '#description' => t('Width of the textfield.') .' '. t('Leaving blank will use the default size.'),
    '#size' => 5,
    '#maxlength' => 10,
  );
  $edit_fields['extra']['disabled'] = array(
    '#type' => 'checkbox',
    '#title' => t("Disabled"),
    '#return_value' => 1,
    '#description' => t('Make this field non-editable. Useful for setting an unchangeable default value.'),
    '#weight' => 3,
    '#default_value' => $currfield['extra']['disabled'],
  );
  $edit_fields['extra']['analysis'] = array(
    '#type' => 'select',
    '#title' => t("Analysis"),
    '#default_value' => $currfield['extra']['analysis'],
    '#description' => t('How to summarize entries in the Analysis view.'),
    '#options' => array('Average', 'Sum'),
  );
  $edit_fields['extra']['min'] = array(
    '#type' => 'textfield',
    '#title' => t("Minimum Value"),
    '#default_value' => $currfield['extra']['min'],
    '#description' => t('Value below which an entry will be rejected.'),
    '#size' => 5,
    '#maxlength' => 10,
  );
  $edit_fields['extra']['max'] = array(
    '#type' => 'textfield',
    '#title' => t("Maximum Value"),
    '#default_value' => $currfield['extra']['max'],
    '#description' => t('Value above which an entry will be rejected.'),
    '#size' => 5,
    '#maxlength' => 10,
  );
  $edit_fields['extra']['type'] = array(
    '#type' => 'select',
    '#title' => t("Number Type"),
    '#default_value' => $currfield['extra']['type'],
    '#description' => t('The type of number that will be accepted. To only accept round numbers, set this to integer.'),
    '#options' => array('Float', 'Integer'),
  );
  return $edit_fields;
}

/**
 * Validation function for the number edit form.
 */
function _webform_edit_number_validate($form_id, $form_values) {
/*
  if ($form_values['user_number']) {
    form_set_value(array('#parents' => array('value')), '%usernumber');
  }
*/
}

/**
 * Build a form item array containing all the properties of this component.
 * @param $component
 *   An array of information describing the component, directly correlating to
 *   the webform_component database schema.
 * @return
 *   An array of a form item to be displayed on the client-side webform.
 */
function _webform_render_number($component) {
  global $user;
  $form_item = array(
    '#type'          => 'textfield',
    '#title'         => $component['name'],
    '#default_value' => _webform_filter_values($component['value']),
    '#required'      => $component['mandatory'],
    '#weight'        => $component['weight'],
    '#description'   => _webform_filter_descriptions($component['extra']['description']),
    '#attributes'    => $component['extra']['attributes'],
    '#disabled'      => $component['extra']['disabled'],
	
    '#field_prefix'  => $component['extra']['field_prefix'],
    '#field_suffix'  => $component['extra']['field_suffix'],
    
     '#prefix'        => '<div class="webform-component-'. $component['type'] .'" id="webform-component-'. $component['form_key'] .'">',
    '#suffix'        => '</div>',
    '#validate'      => array('_webform_validate_number' => array($component)),
  );

  // Change the 'width' option to the correct 'size' option.
  if ($component['extra']['width'] > 0) {
    $form_item['#size'] = $component['extra']['width'];
  }

  return $form_item;
}

/**
 * A Drupal Forms API Validation function. Validates the entered values from
 * number components on the client-side form.
 * @param $formelement
 *   An array of information describing the component, directly correlating to
 *   the webform_component database schema.
 * @return
 *   True if successful, calls a form_set_error if the number is not valid.
 */
function _webform_validate_number($form_element, $component) {
  if (!empty($form_element['#value']) && !is_numeric($form_element['#value'])) {
    form_set_error($component['form_key'], t("%value is not a valid number.", array('%value' => $form_element['#value'])));
    return;
  }
  
  if (isset($component['extra']['type']) && $component['extra']['type'] == 1 && !is_integer($form_element['#value'])) {
    form_set_error($component['form_key'], t("%value is not an integer (round number). Try submitting %integer instead.", array('%value' => $form_element['#value'], '%integer' => round($form_element['#value']))));
  }
  
  if (isset($component['extra']['min']) && strlen($component['extra']['min']) && $component['extra']['min'] > $form_element['#value']) {
    form_set_error($component['form_key'], t("%value is below the minimum allowed value.", array('%value' => $form_element['#value'])));
  }
  
  if (isset($component['extra']['max']) && strlen($component['extra']['max']) && $component['extra']['max'] < $form_element['#value']) {
    form_set_error($component['form_key'], t("%value is above the maximum allowed value.", array('%value' => $form_element['#value'])));
  }
}

/**
 * Display the result of a textfield submission. The output of this function
 * will be displayed under the "results" tab then "submissions".
 * @param $data
 *   An array of information containing the submission result, directly
 *   correlating to the webform_submitted_data database schema.
 * @param $component
 *   An array of information describing the component, directly correlating to
 *   the webform_component database schema.
 * @return
 *   Textual output formatted for human reading.
 */
function _webform_submission_display_number($data, $component, $enabled = false) {
  $form_item = _webform_render_number($component);
  $form_item['#default_value'] = $data['value']['0'];
  $form_item['#disabled'] = !$enabled;
  return $form_item;
}


/**
	 	  * Format the output of emailed data for this component
	 	  *
	 	  * @param $data
	 	  *   A string or array of the submitted data
	 	  * @param $component
	 	  *   An array of information describing the component,
	 	  *   directly correlating to the webform_component database schema.
	 	  *
	 	  * @return string
	 	  *   Textual output to be included in the email.
	 	  */

	function theme_webform_mail_number($data, $component) {
	 	   $value = $data == '' ? '' : ' '. $component['extra']['field_prefix'] . $data . $component['extra']['field_suffix'];
	 	   return $component['name'] .":". $value;}



/**
 * Module specific instance of hook_help().
 */
function _webform_help_number($section) {
  switch ($section) {
    case 'admin/settings/webform#number_description':
      $output = t("A textfield that validates the the input is numeric.");
      break;
  }
  return $output;
}

/**
 * Calculate and returns statistics about results for this component from all
 * submission to this webform. The output of this function will be displayed
 * under the "results" tab then "analysis".
 * @param $component
 *   An array of information describing the component, directly correlating to
 *   the webform_component database schema
 * @return
 *   An array of data rows, each containing a statistic for this component's
 *   submissions.
 */
function _webform_analysis_rows_number($component) {
  $query = 'SELECT data '.
    ' FROM {webform_submitted_data} '.
    ' WHERE nid = %d '.
    ' AND cid = %d';
  $nonblanks = 0;
  $submissions = 0;
  $wordcount = 0;

  $result = db_query($query, $component['nid'], $component['cid']);
  while ($data = db_fetch_array($result)) {
    if ( strlen(trim($data['data'])) > 0 ) {
      $nonblanks++;
      $total += $data['data'];
    }
    $submissions++;
  }
//var_dump($component);

  $rows[0] = array(t('Left Blank'), ($submissions - $nonblanks));
  $rows[1] = array(t('User entered value'), $nonblanks);
  if ($component['extra']['analysis'] == 1) {
	$total = round($total * 100) / 100;
	$rows[2] = array(t('Sum of all values'), ($total !=0 ? $total : '0'));
  }
  else {
	$rows[2] = array(t('Average value'), ($nonblanks !=0 ? number_format($total/$nonblanks, 2) : '0'));
  }
  return $rows;
}

/**
 * Return the result of this component's submission for display in a table. The
 * output of this function will be displayed under the "results" tab then "table".
 * @param $data
 *   An array of information containing the submission result, directly
 *   correlating to the webform_submitted_data database schema
 * @return
 *   Textual output formatted for human reading.
 */
function _webform_table_data_number($data) {
  return check_plain(empty($data['value']['0']) ? "" : $data['value']['0']);
}


/**
 * Return the header information for this component to be displayed in a comma
 * seperated value file. The output of this function will be displayed under the
 * "results" tab then "download".
 * @param $component
 *   An array of information describing the component, directly correlating to
 *   the webform_component database schema.
 * @return
 *   An array of data to be displayed in the first three rows of a CSV file, not
 *   including either prefixed or trailing commas.
 */
function _webform_csv_headers_number($component) {
  $header = array();
  $header[0] = '';
  $header[1] = '';
  $header[2] = $component['name'];
  return $header;
}

/**
 * Return the result of a textfield submission. The output of this function will
 * be displayed under the "results" tab then "submissions".
 * @param $data
 *   An array of information containing the submission result, directly
 *   correlating to the webform_submitted_data database schema.
 * @return
 *   Textual output formatted for CSV, not including either prefixed or trailing
 *   commas.
 */
function _webform_csv_data_number($data) {
  return empty($data['value']['0']) ? "" : $data['value']['0'];
}
